package blastsearch;

import org.biojava.bio.seq.db.SequenceDB;

/**
 * This is a 'static' class used as a Factory for other classes.
 *
 * You need to adapt the constants to your BLAST-Installation (to-do:
 * use environment variables, too).
 *
 * @author Joerg Ruedenauer
 * @version 0.1
 */
public class SearchFactory {

  /**
   * Returns the BLAST Wrapper class (that is a singleton, no need for more).
   */
  public static Blast blast() {
    if (SearchFactory.blast == null) {
      SearchFactory.blast = new Blast();
    }
    return SearchFactory.blast;
  }

  /**
   * Creates a SequenceDB out of a FASTA protein file.
   * @param name name of the file relative to the BlastDBPath
   * @throws java.io.FileNotFoundException if the file doesn't exist
   */
  public static SequenceDB fastaProt2DB(String name)
  throws java.io.FileNotFoundException {
    return new FastaProt2SequenceDBWrapper(name);
  }

  /**
   * Creates an ID for a sequence.
   * This is the name without the gi | ... | part.
   */
  public static String createID(String seqName) {
    int first = seqName.indexOf("|");
    int second = seqName.indexOf("|", first + 1);
    return seqName.substring(second + 1, seqName.length());
  }

  /**
   * Sets the path to the BLAST databases.
   * @param path the path to the BLAST databases.
   */
  public static void setBlastDBPath(String path) {
    SearchFactory.blastDBPath = path;
  }

  /**
   * Returns the path to the BLAST databases.
   */
  public static String getBlastDBPath() {
    return SearchFactory.blastDBPath;
  }

  /**
   * Sets the path to the BLAST program (like /opt/blast/)
   * @param path the path to the BLAST program
   */
  public static void setBlastPath(String path) {
    SearchFactory.blastPath = path;
  }

  /**
   * Returns the path to the BLAST program.
   */
  public static String getBlastPath() {
    return SearchFactory.blastPath;
  }

  /**
   * Stores the instance of Blast (the wrapper to the external program).
   */
  private static Blast blast;

  /**
   * The path to the BLAST program (like /opt/blast/)
   */
  private static String blastPath = "/opt/blast/";

  /**
   * The path to the DBs that can be searched
   */
  private static String blastDBPath = "/opt/blast/data/";

}
